@@ -131,6 +131,12 @@ pub use self::env_var::EnvVar;
 mod env_var_source;
 pub use self::env_var_source::EnvVarSource;
 
+mod ephemeral_container;
+pub use self::ephemeral_container::EphemeralContainer;
+
+mod ephemeral_volume_source;
+pub use self::ephemeral_volume_source::EphemeralVolumeSource;
+
 mod event;
 pub use self::event::Event;
 #[cfg(feature = "api")] pub use self::event::{ReadNamespacedEventOptional, ReadNamespacedEventResponse};
@@ -159,6 +165,9 @@ pub use self::flocker_volume_source::FlockerVolumeSource;
 mod gce_persistent_disk_volume_source;
 pub use self::gce_persistent_disk_volume_source::GCEPersistentDiskVolumeSource;
 
+mod grpc_action;
+pub use self::grpc_action::GRPCAction;
+
 mod git_repo_volume_source;
 pub use self::git_repo_volume_source::GitRepoVolumeSource;
 
@@ -174,9 +183,6 @@ pub use self::http_get_action::HTTPGetAction;
 mod http_header;
 pub use self::http_header::HTTPHeader;
 
-mod handler;
-pub use self::handler::Handler;
-
 mod host_alias;
 pub use self::host_alias::HostAlias;
 
@@ -195,6 +201,9 @@ pub use self::key_to_path::KeyToPath;
 mod lifecycle;
 pub use self::lifecycle::Lifecycle;
 
+mod lifecycle_handler;
+pub use self::lifecycle_handler::LifecycleHandler;
+
 mod limit_range;
 pub use self::limit_range::LimitRange;
 #[cfg(feature = "api")] pub use self::limit_range::{ReadNamespacedLimitRangeOptional, ReadNamespacedLimitRangeResponse};
@@ -225,6 +234,9 @@ pub use self::namespace::Namespace;
 #[cfg(feature = "api")] pub use self::namespace::{ReadNamespaceOptional, ReadNamespaceResponse};
 #[cfg(feature = "api")] pub use self::namespace::{ReadNamespaceStatusOptional, ReadNamespaceStatusResponse};
 
+mod namespace_condition;
+pub use self::namespace_condition::NamespaceCondition;
+
 mod namespace_spec;
 pub use self::namespace_spec::NamespaceSpec;
 
@@ -307,6 +319,9 @@ pub use self::persistent_volume_claim_spec::PersistentVolumeClaimSpec;
 mod persistent_volume_claim_status;
 pub use self::persistent_volume_claim_status::PersistentVolumeClaimStatus;
 
+mod persistent_volume_claim_template;
+pub use self::persistent_volume_claim_template::PersistentVolumeClaimTemplate;
+
 mod persistent_volume_claim_volume_source;
 pub use self::persistent_volume_claim_volume_source::PersistentVolumeClaimVolumeSource;
 
@@ -338,6 +353,7 @@ pub use self::pod::Pod;
 #[cfg(feature = "api")] pub use self::pod::ConnectPutNamespacedPodProxyOptional;
 #[cfg(feature = "api")] pub use self::pod::ConnectPutNamespacedPodProxyWithPathOptional;
 #[cfg(feature = "api")] pub use self::pod::{ReadNamespacedPodOptional, ReadNamespacedPodResponse};
+#[cfg(feature = "api")] pub use self::pod::{ReadNamespacedPodEphemeralcontainersOptional, ReadNamespacedPodEphemeralcontainersResponse};
 #[cfg(feature = "api")] pub use self::pod::{ReadNamespacedPodLogOptional, ReadNamespacedPodLogResponse};
 #[cfg(feature = "api")] pub use self::pod::{ReadNamespacedPodStatusOptional, ReadNamespacedPodStatusResponse};
 
@@ -359,6 +375,12 @@ pub use self::pod_dns_config::PodDNSConfig;
 mod pod_dns_config_option;
 pub use self::pod_dns_config_option::PodDNSConfigOption;
 
+mod pod_ip;
+pub use self::pod_ip::PodIP;
+
+mod pod_os;
+pub use self::pod_os::PodOS;
+
 mod pod_readiness_gate;
 pub use self::pod_readiness_gate::PodReadinessGate;
 
@@ -378,6 +400,9 @@ pub use self::pod_template::PodTemplate;
 mod pod_template_spec;
 pub use self::pod_template_spec::PodTemplateSpec;
 
+mod port_status;
+pub use self::port_status::PortStatus;
+
 mod portworx_volume_source;
 pub use self::portworx_volume_source::PortworxVolumeSource;
 
@@ -445,6 +470,9 @@ pub use self::scope_selector::ScopeSelector;
 mod scoped_resource_selector_requirement;
 pub use self::scoped_resource_selector_requirement::ScopedResourceSelectorRequirement;
 
+mod seccomp_profile;
+pub use self::seccomp_profile::SeccompProfile;
+
 mod secret;
 pub use self::secret::Secret;
 #[cfg(feature = "api")] pub use self::secret::{ReadNamespacedSecretOptional, ReadNamespacedSecretResponse};
@@ -525,6 +553,9 @@ pub use self::topology_selector_label_requirement::TopologySelectorLabelRequirem
 mod topology_selector_term;
 pub use self::topology_selector_term::TopologySelectorTerm;
 
+mod topology_spread_constraint;
+pub use self::topology_spread_constraint::TopologySpreadConstraint;
+
 mod typed_local_object_reference;
 pub use self::typed_local_object_reference::TypedLocalObjectReference;
 
@@ -548,3 +579,6 @@ pub use self::vsphere_virtual_disk_volume_source::VsphereVirtualDiskVolumeSource
 
 mod weighted_pod_affinity_term;
 pub use self::weighted_pod_affinity_term::WeightedPodAffinityTerm;
+
+mod windows_security_context_options;
+pub use self::windows_security_context_options::WindowsSecurityContextOptions;
